=============================
Dingos
=============================


A Django app that provides a generic framework for managing structured information in a generic way.

Documentation
-------------

The full documentation is at http://django-dingos.rtfd.org.

Quickstart
----------

Please refer to the quickstart information of MANTIS, available at http://django-mantis.rtfd.org.

Acknowledgments
---------------


The basic layout for this Django app with out-of-the-box configuration of ``setup.py`` for
easy build, submission to PyPi, etc., and Sphinx documentation tree was generated with Audrey Roy's excellent `Cookiecutter`_
and Daniel Greenfield's `cookiecutter-djangopackage`_ template.


.. _Cookiecutter: https://github.com/audreyr/cookiecutter


.. _cookiecutter-djangopackage: https://github.com/pydanny/cookiecutter-djangopackage
